@@ -2,6 +2,18 @@ from selenium.webdriver.common.keys import Keys
 
 
 def clear(self, log=True, press_enter=False):
+    """
+    Clear the page object.
+
+    :param bool log: whether to log or not (defualt is True)
+    :param bool press_enter: whether to press enter key after
+        the element is cleared (defualt is False)
+    :returns: `self`
+    :rtype: `PageObjectBase` instance
+    :raises NoSuchElementException: if the element cannot be found
+    :raises InvalidSelectorException: if the selector is invalid
+        or doesn't select an element
+    """
     if log:
         self.logger.info('clearing {}'.format(self._log_id_short))
         self.logger.debug('clearing page object; {}'.format(self._log_id_long))
